..  This file is part of Invenio
    Copyright (C) 2014 CERN.

    Invenio is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Invenio is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Invenio; if not, write to the Free Software Foundation, Inc.,
    59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.

Demo
====

There are several Invenio installations that you can have a look at in
order to see it in action:

Demo Sites
----------

`Atlantis Institute of Fictive Science <http://demo.invenio-software.org/>`_
    *running Invenio 1.2.1, released 2015-05-21*

    Atlantis Institute of Fictive Science is an official demo site of
    Invenio.  It demonstrates a basic setup of Invenio. You could
    (should) obtain this site if you install Invenio for the first
    time, by lauching ``inveniocfg --create-demo-site`` and
    ``inveniocfg --load-demo-records``. This is useful to verify the
    functionality of your installation prior to customizing the system
    for production.

Production Sites
----------------

.. image:: /_static/CDS20120611.png
   :width: 200 px
   :align: right

`CERN Document Server <http://cds.cern.ch>`_
   *CERN, Geneva, Switzerland*

   At CERN, Invenio manages over 800,000 bibliographic records and
   350,000 fulltext documents, organized in more than 500
   collections, covering preprints, articles, books, journals,
   photographs, videos and more, of interest to people working in
   particle physics. You can check out this site if you want to see
   the performance and scalability of Invenio.


.. image:: /_static/Inspire20120611.png
   :width: 200 px
   :align: right

`INSPIRE <http://inspirebeta.net>`_
   *CERN, Geneva, Switzerland*

   INSPIRE is the high-energy physics information system that combines the
   successful `SPIRES <http://www.slac.stanford.edu/spires>`_ database
   content, curated at `DESY <http://www.desy.de/>`_, `Fermilab
   <http://www.fnal.gov/>`_ and `SLAC <http://www.slac.stanford.edu/>`_
   for decades, with the Invenio digital library technology developed at
   `CERN <http://www.cern.ch/>`_. INSPIRE is run by a collaboration of the
   four labs and interacts closely with high-energy physics publishers,
   `arXiv.org <http://arxiv.org/>`_, `NASA-ADS <http://adswww.harvard.edu/>`_,
   `PDG <http://pdg.lbl.gov/>`_, and other information resources.

[...]
